==> react-ui-5.0.0.tgz: package/Monogram.js <==
/******/ (() => {
    // webpackBootstrap
    /******/ "use strict";
    /******/ // The require scope
    /******/    var e = {};
    /******/
    /************************************************************************/
    /******/ /* webpack/runtime/compat get default export */
    /******/    (() => {
        /******/ // getDefaultExport function for compatibility with non-harmony modules
        /******/ e.n = r => {
            /******/ var t = r && r.__esModule ? 
            /******/ () => r["default"]
            /******/ : () => r
            /******/;
            e.d(t, {
                a: t
            });
            /******/            return t;
            /******/        };
        /******/    })();
    /******/
    /******/ /* webpack/runtime/define property getters */
    /******/    (() => {
        /******/ // define getter functions for harmony exports
        /******/ e.d = (r, t) => {
            /******/ for (var n in t) {
                /******/ if (e.o(t, n) && !e.o(r, n)) {
                    /******/ Object.defineProperty(r, n, {
                        enumerable: true,
                        get: t[n]
                    });
                    /******/                }
                /******/            }
            /******/        };
        /******/    })();
    /******/
    /******/ /* webpack/runtime/hasOwnProperty shorthand */
    /******/    (() => {
        /******/ e.o = (e, r) => Object.prototype.hasOwnProperty.call(e, r)
        /******/;
    })();
    /******/
    /******/ /* webpack/runtime/make namespace object */
    /******/    (() => {
        /******/ // define __esModule on exports
        /******/ e.r = e => {
            /******/ if (typeof Symbol !== "undefined" && Symbol.toStringTag) {
                /******/ Object.defineProperty(e, Symbol.toStringTag, {
                    value: "Module"
                });
                /******/            }
            /******/            Object.defineProperty(e, "__esModule", {
                value: true
            });
            /******/        };
        /******/    })();
    /******/
    /************************************************************************/    var r = {};
    // ESM COMPAT FLAG
        e.r(r);
    // EXPORTS
        e.d(r, {
        default: () => /* reexport */ U,
        getInitials: () => /* reexport */ T
    });
    // CONCATENATED MODULE: external "react"
    const t = require("react");
    var n =  e.n(t);
    // CONCATENATED MODULE: external "prop-types"
    const i = require("prop-types");
    var o =  e.n(i);
    // CONCATENATED MODULE: external "lodash/omit"
    const a = require("lodash/omit");
    var l =  e.n(a);
    // CONCATENATED MODULE: external "styled-components"
    const c = require("styled-components");
    var s =  e.n(c);
    // CONCATENATED MODULE: external "@splunk/react-ui/Clickable"
    const u = require("@splunk/react-ui/Clickable");
    var f =  e.n(u);
    // CONCATENATED MODULE: external "@splunk/themes"
    const p = require("@splunk/themes");
    // CONCATENATED MODULE: ./src/Monogram/MonogramStyles.ts
    // Thanks: https://gist.github.com/hyamamoto/fd435505d29ebfa3d9716fd2be8d42f0
    var b = function e(r) {
        var t = 0;
        for (var n = 0; n < r.length; ) {
            t = (t << 5) - t + r.charCodeAt(n++) | 0;
 // eslint-disable-line no-bitwise, no-plusplus
                }
        return t;
    };
    var d = [ "#006d9c", "#ec9960", "#af575a", "#62b3b2", "#4fa484", "#f8be34", "#5a4575", "#708794", "#294e70", "#b6c75a", "#5cc05c", "#007abd", "#dc4e41", "#f1813f", "#f8be34", "#53a051", "#006d9c", "#77d6d8", "#f589ad", "#6a2c5d" ];
    var m = (0, c.css)([ "", ";align-items:center;justify-content:center;border-radius:50%;font-weight:normal;", " background-color:", ";", ";& + &{margin-left:4px;}" ], p.mixins.reset("inline-flex"), (0, 
    p.pick)({
        prisma: (0, c.css)([ "color:", ";" ], p.variables.contentColorActive)
    }), (function(e) {
        var r = e.$backgroundColor, t = e.$initials;
        if (r === "theme") {
            return (0, p.pick)({
                enterprise: {
                    dark: p.variables.gray45,
                    light: p.variables.gray92
                },
                prisma: p.variables.neutral100
            });
        }
        if (r === "auto") {
            return d[b(t) % d.length];
        }
        return r;
    }), (function(e) {
        var r = e.$size;
        if (typeof r === "number") {
            return (0, c.css)([ "height:", "px;width:", "px;" ], r, r);
        }
        if (typeof r === "string") {
            return (0, p.pickVariant)("$size", {
                small: (0, c.css)([ "font-size:", ";", "" ], p.variables.fontSize, (0, p.pick)({
                    enterprise: (0, c.css)([ "height:32px;width:32px;" ]),
                    prisma: (0, c.css)([ "height:24px;width:24px;" ])
                })),
                medium: (0, c.css)([ "height:48px;width:48px;font-size:", ";" ], p.variables.fontSize),
                large: (0, c.css)([ "height:80px;width:80px;font-size:", ";" ], p.variables.fontSizeXXLarge),
                xlarge: (0, c.css)([ "width:144px;height:144px;font-size:36px;font-weight:700;" ])
            });
        }
        return (0, c.css)([ "height:48px;width:48px;font-size:", ";" ], p.variables.fontSize);
    }));
    var y = s().div.withConfig({
        displayName: "MonogramStyles__Styled",
        componentId: "r5ud6k-0"
    })([ "", "" ], m);
    var v = s()(f()).withConfig({
        displayName: "MonogramStyles__StyledClickableComponent",
        componentId: "r5ud6k-1"
    })([ "", "" ], m);
    var g = s()(v).withConfig({
        displayName: "MonogramStyles__StyledClickable",
        componentId: "r5ud6k-2"
    })([ "cursor:pointer;position:relative;:focus,:hover{", "}:focus{box-shadow:", ";z-index:1;}:active{", "}" ], (0, 
    p.pick)({
        enterprise: (0, c.css)([ "box-shadow:", ";" ], p.variables.focusShadowInset),
        prisma: (0, c.css)([ "border:1px solid transparent;background-color:", ";" ], p.variables.neutral200)
    }), (0, p.pick)({
        enterprise: p.variables.focusShadowInset,
        prisma: p.variables.focusShadow
    }), (0, p.pick)({
        enterprise: (0, c.css)([ "opacity:0.85;" ]),
        prisma: (0, c.css)([ "border:1px solid transparent;background-color:", ";opacity:1;" ], p.variables.neutral200)
    }));
    var h = s().span.withConfig({
        displayName: "MonogramStyles__Initials",
        componentId: "r5ud6k-3"
    })([ "opacity:0.8;text-transform:capitalize;" ]);
    // CONCATENATED MODULE: ./src/Monogram/Monogram.tsx
    function O(e) {
        "@babel/helpers - typeof";
        return O = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(e) {
            return typeof e;
        } : function(e) {
            return e && "function" == typeof Symbol && e.constructor === Symbol && e !== Symbol.prototype ? "symbol" : typeof e;
        }, O(e);
    }
    function k(e, r) {
        var t = Object.keys(e);
        if (Object.getOwnPropertySymbols) {
            var n = Object.getOwnPropertySymbols(e);
            r && (n = n.filter((function(r) {
                return Object.getOwnPropertyDescriptor(e, r).enumerable;
            }))), t.push.apply(t, n);
        }
        return t;
    }
    function w(e) {
        for (var r = 1; r < arguments.length; r++) {
            var t = null != arguments[r] ? arguments[r] : {};
            r % 2 ? k(Object(t), !0).forEach((function(r) {
                S(e, r, t[r]);
            })) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : k(Object(t)).forEach((function(r) {
                Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r));
            }));
        }
        return e;
    }
    function S(e, r, t) {
        return (r = j(r)) in e ? Object.defineProperty(e, r, {
            value: t,
            enumerable: !0,
            configurable: !0,
            writable: !0
        }) : e[r] = t, e;
    }
    function j(e) {
        var r = x(e, "string");
        return "symbol" == O(r) ? r : r + "";
    }
    function x(e, r) {
        if ("object" != O(e) || !e) return e;
        var t = e[Symbol.toPrimitive];
        if (void 0 !== t) {
            var n = t.call(e, r || "default");
            if ("object" != O(n)) return n;
            throw new TypeError("@@toPrimitive must return a primitive value.");
        }
        return ("string" === r ? String : Number)(e);
    }
    function C() {
        return C = Object.assign ? Object.assign.bind() : function(e) {
            for (var r = 1; r < arguments.length; r++) {
                var t = arguments[r];
                for (var n in t) {
                    ({}).hasOwnProperty.call(t, n) && (e[n] = t[n]);
                }
            }
            return e;
        }, C.apply(null, arguments);
    }
    function z(e, r) {
        return A(e) || E(e, r) || I(e, r) || P();
    }
    function P() {
        throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
    }
    function I(e, r) {
        if (e) {
            if ("string" == typeof e) return _(e, r);
            var t = {}.toString.call(e).slice(8, -1);
            return "Object" === t && e.constructor && (t = e.constructor.name), "Map" === t || "Set" === t ? Array.from(e) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _(e, r) : void 0;
        }
    }
    function _(e, r) {
        (null == r || r > e.length) && (r = e.length);
        for (var t = 0, n = Array(r); t < r; t++) {
            n[t] = e[t];
        }
        return n;
    }
    function E(e, r) {
        var t = null == e ? null : "undefined" != typeof Symbol && e[Symbol.iterator] || e["@@iterator"];
        if (null != t) {
            var n, i, o, a, l = [], c = !0, s = !1;
            try {
                if (o = (t = t.call(e)).next, 0 === r) {
                    if (Object(t) !== t) return;
                    c = !1;
                } else for (;!(c = (n = o.call(t)).done) && (l.push(n.value), l.length !== r); c = !0) {
                }
            } catch (e) {
                s = !0, i = e;
            } finally {
                try {
                    if (!c && null != t["return"] && (a = t["return"](), Object(a) !== a)) return;
                } finally {
                    if (s) throw i;
                }
            }
            return l;
        }
    }
    function A(e) {
        if (Array.isArray(e)) return e;
    }
    function M(e, r) {
        if (null == e) return {};
        var t, n, i = $(e, r);
        if (Object.getOwnPropertySymbols) {
            var o = Object.getOwnPropertySymbols(e);
            for (n = 0; n < o.length; n++) {
                t = o[n], r.includes(t) || {}.propertyIsEnumerable.call(e, t) && (i[t] = e[t]);
            }
        }
        return i;
    }
    function $(e, r) {
        if (null == e) return {};
        var t = {};
        for (var n in e) {
            if ({}.hasOwnProperty.call(e, n)) {
                if (r.includes(n)) continue;
                t[n] = e[n];
            }
        }
        return t;
    }
    /** @public */    var q = {
        backgroundColor: o().string,
        elementRef: o().oneOfType([ o().func, o().object ]),
        initials: o().string.isRequired,
        name: o().string,
        onClick: o().func,
        size: o().oneOfType([ o().oneOf([ "small", "medium", "large" ]), o().number ])
    };
    function R(e) {
        return !!e.onClick;
    }
    /**
 * Returns a suitable set of initials for a name. Uses the first character of each
 * name segment and omits middle segments if the segment count is greater than three.
 * @param {string} name - The full name.
 * @returns {string} Limited to three characters. Empty if `name` is empty.
 * @public
 */    function T(e) {
        var r = (e.match(/[^\s-]+/g) || []).map((function(e) {
            return e[0];
        })).join("");
        return r.length > 3 ? "".concat(r[0]).concat(r[r.length - 1]) : r;
    }
    function N(e) {
        var r = e.backgroundColor, t = e.initials, n = e.size, i = M(e, [ "backgroundColor", "initials", "size" ]);
        var o = {
            "data-test": "monogram",
            $backgroundColor: r,
            $initials: t,
            $size: n
        };
        return [ o, i ];
    }
    function D(e) {
        var r = N(e), i = z(r, 2), o = i[0], a = i[1];
        var c = a.children, s = a.elementRef, u = a.name, f = a.onClick, p = M(a, [ "children", "elementRef", "name", "onClick" ]);
        var b = (0, t.useCallback)((function(e) {
            f(e, {
                name: u
            });
        }), [ f, u ]);
        
        return n().createElement(g, C({
            elementRef: s,
            onClick: b
        }, o, l()(p, Object.keys(q))), c);
    }
    function X(e) {
        var r = N(e), t = z(r, 2), i = t[0], o = t[1];
        var a = o.children, c = o.elementRef, s = M(o, [ "children", "elementRef" ]);
        
        return n().createElement(y, C({
            ref: c
        }, i, l()(s, Object.keys(q))), a);
    }
    function L(e) {
        var r = e.backgroundColor, t = r === void 0 ? "theme" : r, i = e.initials, o = e.size, a = o === void 0 ? "medium" : o, l = M(e, [ "backgroundColor", "initials", "size" ]);
        // @docs-props-type MonogramPropsBase
                if (false) {}
        var c =  n().createElement(h, {
            "data-test": "initials"
        }, i);
        var s = w({
            backgroundColor: t,
            size: a,
            initials: i
        }, l);
        return R(s) ?  n().createElement(D, s, c) :  n().createElement(X, s, c);
    }
    L.propTypes = q;
    /* harmony default export */    const U = L;
    // CONCATENATED MODULE: ./src/Monogram/index.ts
    module.exports = r;
    /******/})();

==> react-ui-5.1.0.tgz: package/Monogram.js <==
/******/ (() => {
    // webpackBootstrap
    /******/ "use strict";
    /******/ // The require scope
    /******/    var e = {};
    /******/
    /************************************************************************/
    /******/ /* webpack/runtime/compat get default export */
    /******/    (() => {
        /******/ // getDefaultExport function for compatibility with non-harmony modules
        /******/ e.n = r => {
            /******/ var t = r && r.__esModule ? 
            /******/ () => r["default"]
            /******/ : () => r
            /******/;
            e.d(t, {
                a: t
            });
            /******/            return t;
            /******/        };
        /******/    })();
    /******/
    /******/ /* webpack/runtime/define property getters */
    /******/    (() => {
        /******/ // define getter functions for harmony exports
        /******/ e.d = (r, t) => {
            /******/ for (var n in t) {
                /******/ if (e.o(t, n) && !e.o(r, n)) {
                    /******/ Object.defineProperty(r, n, {
                        enumerable: true,
                        get: t[n]
                    });
                    /******/                }
                /******/            }
            /******/        };
        /******/    })();
    /******/
    /******/ /* webpack/runtime/hasOwnProperty shorthand */
    /******/    (() => {
        /******/ e.o = (e, r) => Object.prototype.hasOwnProperty.call(e, r)
        /******/;
    })();
    /******/
    /******/ /* webpack/runtime/make namespace object */
    /******/    (() => {
        /******/ // define __esModule on exports
        /******/ e.r = e => {
            /******/ if (typeof Symbol !== "undefined" && Symbol.toStringTag) {
                /******/ Object.defineProperty(e, Symbol.toStringTag, {
                    value: "Module"
                });
                /******/            }
            /******/            Object.defineProperty(e, "__esModule", {
                value: true
            });
            /******/        };
        /******/    })();
    /******/
    /************************************************************************/    var r = {};
    // ESM COMPAT FLAG
        e.r(r);
    // EXPORTS
        e.d(r, {
        default: () => /* reexport */ U,
        getInitials: () => /* reexport */ T
    });
    // CONCATENATED MODULE: external "react"
    const t = require("react");
    var n =  e.n(t);
    // CONCATENATED MODULE: external "lodash/omit"
    const i = require("lodash/omit");
    var o =  e.n(i);
    // CONCATENATED MODULE: external "prop-types"
    const a = require("prop-types");
    var l =  e.n(a);
    // CONCATENATED MODULE: external "styled-components"
    const c = require("styled-components");
    var s =  e.n(c);
    // CONCATENATED MODULE: external "@splunk/react-ui/Clickable"
    const u = require("@splunk/react-ui/Clickable");
    var f =  e.n(u);
    // CONCATENATED MODULE: external "@splunk/themes"
    const p = require("@splunk/themes");
    // CONCATENATED MODULE: ./src/Monogram/MonogramStyles.ts
    // Thanks: https://gist.github.com/hyamamoto/fd435505d29ebfa3d9716fd2be8d42f0
    var b = function e(r) {
        var t = 0;
        for (var n = 0; n < r.length; ) {
            t = (t << 5) - t + r.charCodeAt(n++) | 0;
 // eslint-disable-line no-bitwise, no-plusplus
                }
        return t;
    };
    var d = [ "#006d9c", "#ec9960", "#af575a", "#62b3b2", "#4fa484", "#f8be34", "#5a4575", "#708794", "#294e70", "#b6c75a", "#5cc05c", "#007abd", "#dc4e41", "#f1813f", "#f8be34", "#53a051", "#006d9c", "#77d6d8", "#f589ad", "#6a2c5d" ];
    var m = (0, c.css)([ "", ";align-items:center;justify-content:center;border-radius:50%;font-weight:normal;", " background-color:", ";", ";& + &{margin-left:4px;}" ], p.mixins.reset("inline-flex"), (0, 
    p.pick)({
        prisma: (0, c.css)([ "color:", ";" ], p.variables.contentColorActive)
    }), (function(e) {
        var r = e.$backgroundColor, t = e.$initials;
        if (r === "theme") {
            return (0, p.pick)({
                enterprise: {
                    dark: p.variables.gray45,
                    light: p.variables.gray92
                },
                prisma: p.variables.neutral100
            });
        }
        if (r === "auto") {
            return d[b(t) % d.length];
        }
        return r;
    }), (function(e) {
        var r = e.$size;
        if (typeof r === "number") {
            return (0, c.css)([ "height:", "px;width:", "px;" ], r, r);
        }
        if (typeof r === "string") {
            return (0, p.pickVariant)("$size", {
                small: (0, c.css)([ "font-size:", ";", "" ], p.variables.fontSize, (0, p.pick)({
                    enterprise: (0, c.css)([ "height:32px;width:32px;" ]),
                    prisma: (0, c.css)([ "height:24px;width:24px;" ])
                })),
                medium: (0, c.css)([ "height:48px;width:48px;font-size:", ";" ], p.variables.fontSize),
                large: (0, c.css)([ "height:80px;width:80px;font-size:", ";" ], p.variables.fontSizeXXLarge),
                xlarge: (0, c.css)([ "width:144px;height:144px;font-size:36px;font-weight:700;" ])
            });
        }
        return (0, c.css)([ "height:48px;width:48px;font-size:", ";" ], p.variables.fontSize);
    }));
    var y = s().div.withConfig({
        displayName: "MonogramStyles__Styled",
        componentId: "r5ud6k-0"
    })([ "", "" ], m);
    var v = s()(f()).withConfig({
        displayName: "MonogramStyles__StyledClickableComponent",
        componentId: "r5ud6k-1"
    })([ "", "" ], m);
    var g = s()(v).withConfig({
        displayName: "MonogramStyles__StyledClickable",
        componentId: "r5ud6k-2"
    })([ "cursor:pointer;position:relative;:focus,:hover{", "}:focus{box-shadow:", ";z-index:1;}:active{", "}" ], (0, 
    p.pick)({
        enterprise: (0, c.css)([ "box-shadow:", ";" ], p.variables.focusShadowInset),
        prisma: (0, c.css)([ "border:1px solid transparent;background-color:", ";" ], p.variables.neutral200)
    }), (0, p.pick)({
        enterprise: p.variables.focusShadowInset,
        prisma: p.variables.focusShadow
    }), (0, p.pick)({
        enterprise: (0, c.css)([ "opacity:0.85;" ]),
        prisma: (0, c.css)([ "border:1px solid transparent;background-color:", ";opacity:1;" ], p.variables.neutral200)
    }));
    var h = s().span.withConfig({
        displayName: "MonogramStyles__Initials",
        componentId: "r5ud6k-3"
    })([ "opacity:0.8;text-transform:capitalize;" ]);
    // CONCATENATED MODULE: ./src/Monogram/Monogram.tsx
    function O(e) {
        "@babel/helpers - typeof";
        return O = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(e) {
            return typeof e;
        } : function(e) {
            return e && "function" == typeof Symbol && e.constructor === Symbol && e !== Symbol.prototype ? "symbol" : typeof e;
        }, O(e);
    }
    function k(e, r) {
        var t = Object.keys(e);
        if (Object.getOwnPropertySymbols) {
            var n = Object.getOwnPropertySymbols(e);
            r && (n = n.filter((function(r) {
                return Object.getOwnPropertyDescriptor(e, r).enumerable;
            }))), t.push.apply(t, n);
        }
        return t;
    }
    function w(e) {
        for (var r = 1; r < arguments.length; r++) {
            var t = null != arguments[r] ? arguments[r] : {};
            r % 2 ? k(Object(t), !0).forEach((function(r) {
                S(e, r, t[r]);
            })) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : k(Object(t)).forEach((function(r) {
                Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r));
            }));
        }
        return e;
    }
    function S(e, r, t) {
        return (r = j(r)) in e ? Object.defineProperty(e, r, {
            value: t,
            enumerable: !0,
            configurable: !0,
            writable: !0
        }) : e[r] = t, e;
    }
    function j(e) {
        var r = x(e, "string");
        return "symbol" == O(r) ? r : r + "";
    }
    function x(e, r) {
        if ("object" != O(e) || !e) return e;
        var t = e[Symbol.toPrimitive];
        if (void 0 !== t) {
            var n = t.call(e, r || "default");
            if ("object" != O(n)) return n;
            throw new TypeError("@@toPrimitive must return a primitive value.");
        }
        return ("string" === r ? String : Number)(e);
    }
    function C() {
        return C = Object.assign ? Object.assign.bind() : function(e) {
            for (var r = 1; r < arguments.length; r++) {
                var t = arguments[r];
                for (var n in t) {
                    ({}).hasOwnProperty.call(t, n) && (e[n] = t[n]);
                }
            }
            return e;
        }, C.apply(null, arguments);
    }
    function z(e, r) {
        return A(e) || E(e, r) || I(e, r) || P();
    }
    function P() {
        throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
    }
    function I(e, r) {
        if (e) {
            if ("string" == typeof e) return _(e, r);
            var t = {}.toString.call(e).slice(8, -1);
            return "Object" === t && e.constructor && (t = e.constructor.name), "Map" === t || "Set" === t ? Array.from(e) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _(e, r) : void 0;
        }
    }
    function _(e, r) {
        (null == r || r > e.length) && (r = e.length);
        for (var t = 0, n = Array(r); t < r; t++) {
            n[t] = e[t];
        }
        return n;
    }
    function E(e, r) {
        var t = null == e ? null : "undefined" != typeof Symbol && e[Symbol.iterator] || e["@@iterator"];
        if (null != t) {
            var n, i, o, a, l = [], c = !0, s = !1;
            try {
                if (o = (t = t.call(e)).next, 0 === r) {
                    if (Object(t) !== t) return;
                    c = !1;
                } else for (;!(c = (n = o.call(t)).done) && (l.push(n.value), l.length !== r); c = !0) {
                }
            } catch (e) {
                s = !0, i = e;
            } finally {
                try {
                    if (!c && null != t["return"] && (a = t["return"](), Object(a) !== a)) return;
                } finally {
                    if (s) throw i;
                }
            }
            return l;
        }
    }
    function A(e) {
        if (Array.isArray(e)) return e;
    }
    function M(e, r) {
        if (null == e) return {};
        var t, n, i = $(e, r);
        if (Object.getOwnPropertySymbols) {
            var o = Object.getOwnPropertySymbols(e);
            for (n = 0; n < o.length; n++) {
                t = o[n], r.includes(t) || {}.propertyIsEnumerable.call(e, t) && (i[t] = e[t]);
            }
        }
        return i;
    }
    function $(e, r) {
        if (null == e) return {};
        var t = {};
        for (var n in e) {
            if ({}.hasOwnProperty.call(e, n)) {
                if (r.includes(n)) continue;
                t[n] = e[n];
            }
        }
        return t;
    }
    /** @public */    var q = {
        backgroundColor: l().string,
        elementRef: l().oneOfType([ l().func, l().object ]),
        initials: l().string.isRequired,
        name: l().string,
        onClick: l().func,
        size: l().oneOfType([ l().oneOf([ "small", "medium", "large" ]), l().number ])
    };
    function R(e) {
        return !!e.onClick;
    }
    /**
 * Returns a suitable set of initials for a name. Uses the first character of each
 * name segment and omits middle segments if the segment count is greater than three.
 * @param {string} name - The full name.
 * @returns {string} Limited to three characters. Empty if `name` is empty.
 * @public
 */    function T(e) {
        var r = (e.match(/[^\s-]+/g) || []).map((function(e) {
            return e[0];
        })).join("");
        return r.length > 3 ? "".concat(r[0]).concat(r[r.length - 1]) : r;
    }
    function N(e) {
        var r = e.backgroundColor, t = e.initials, n = e.size, i = M(e, [ "backgroundColor", "initials", "size" ]);
        var o = {
            "data-test": "monogram",
            $backgroundColor: r,
            $initials: t,
            $size: n
        };
        return [ o, i ];
    }
    function D(e) {
        var r = N(e), i = z(r, 2), a = i[0], l = i[1];
        var c = l.children, s = l.elementRef, u = l.name, f = l.onClick, p = M(l, [ "children", "elementRef", "name", "onClick" ]);
        var b = (0, t.useCallback)((function(e) {
            f(e, {
                name: u
            });
        }), [ f, u ]);
        
        return n().createElement(g, C({
            elementRef: s,
            onClick: b
        }, a, o()(p, Object.keys(q))), c);
    }
    function X(e) {
        var r = N(e), t = z(r, 2), i = t[0], a = t[1];
        var l = a.children, c = a.elementRef, s = M(a, [ "children", "elementRef" ]);
        
        return n().createElement(y, C({
            ref: c
        }, i, o()(s, Object.keys(q))), l);
    }
    function L(e) {
        var r = e.backgroundColor, t = r === void 0 ? "theme" : r, i = e.initials, o = e.size, a = o === void 0 ? "medium" : o, l = M(e, [ "backgroundColor", "initials", "size" ]);
        // @docs-props-type MonogramPropsBase
                if (false) {}
        var c =  n().createElement(h, {
            "data-test": "initials"
        }, i);
        var s = w({
            backgroundColor: t,
            size: a,
            initials: i
        }, l);
        return R(s) ?  n().createElement(D, s, c) :  n().createElement(X, s, c);
    }
    L.propTypes = q;
    /* harmony default export */    const U = L;
    // CONCATENATED MODULE: ./src/Monogram/index.ts
    module.exports = r;
    /******/})();
